# hummer



[![Build Status](https://travis-ci.com/Jack-Kingdom/hummer.svg?branch=master)](https://travis-ci.com/Jack-Kingdom/hummer)

portal access utils.
![hummer](https://raw.githubusercontent.com/wiki/Jack-Kingdom/humer/assets/hummer.jpg)

## Install
```shell
pip install hummer
```

## Documentation
Check [wiki](https://github.com/Jack-Kingdom/hummer/wiki) for details.

## LICENSE
MIT